# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from flyteidl.service import auth_pb2 as flyteidl_dot_service_dot_auth__pb2


class AuthMetadataServiceStub(object):
  """The following defines an RPC service that is also served over HTTP via grpc-gateway.
  Standard response codes for both are defined here: https://github.com/grpc-ecosystem/grpc-gateway/blob/master/runtime/errors.go
  RPCs defined in this service must be anonymously accessible.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetOAuth2Metadata = channel.unary_unary(
        '/flyteidl.service.AuthMetadataService/GetOAuth2Metadata',
        request_serializer=flyteidl_dot_service_dot_auth__pb2.OAuth2MetadataRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_auth__pb2.OAuth2MetadataResponse.FromString,
        )
    self.GetPublicClientConfig = channel.unary_unary(
        '/flyteidl.service.AuthMetadataService/GetPublicClientConfig',
        request_serializer=flyteidl_dot_service_dot_auth__pb2.PublicClientAuthConfigRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_auth__pb2.PublicClientAuthConfigResponse.FromString,
        )


class AuthMetadataServiceServicer(object):
  """The following defines an RPC service that is also served over HTTP via grpc-gateway.
  Standard response codes for both are defined here: https://github.com/grpc-ecosystem/grpc-gateway/blob/master/runtime/errors.go
  RPCs defined in this service must be anonymously accessible.
  """

  def GetOAuth2Metadata(self, request, context):
    """Anonymously accessible. Retrieves local or external oauth authorization server metadata.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetPublicClientConfig(self, request, context):
    """Anonymously accessible. Retrieves the client information clients should use when initiating OAuth2 authorization
    requests.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AuthMetadataServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetOAuth2Metadata': grpc.unary_unary_rpc_method_handler(
          servicer.GetOAuth2Metadata,
          request_deserializer=flyteidl_dot_service_dot_auth__pb2.OAuth2MetadataRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_auth__pb2.OAuth2MetadataResponse.SerializeToString,
      ),
      'GetPublicClientConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetPublicClientConfig,
          request_deserializer=flyteidl_dot_service_dot_auth__pb2.PublicClientAuthConfigRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_auth__pb2.PublicClientAuthConfigResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'flyteidl.service.AuthMetadataService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/auth.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/auth.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n\x1b\x66lyteidl/service/auth.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\x17\n\x15OAuth2MetadataRequest\"\xa6\x02\n\x16OAuth2MetadataResponse\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x1e\n\x16\x61uthorization_endpoint\x18\x02 \x01(\t\x12\x16\n\x0etoken_endpoint\x18\x03 \x01(\t\x12 \n\x18response_types_supported\x18\x04 \x03(\t\x12\x18\n\x10scopes_supported\x18\x05 \x03(\t\x12-\n%token_endpoint_auth_methods_supported\x18\x06 \x03(\t\x12\x10\n\x08jwks_uri\x18\x07 \x01(\t\x12(\n code_challenge_methods_supported\x18\x08 \x03(\t\x12\x1d\n\x15grant_types_supported\x18\t \x03(\t\"\x1f\n\x1dPublicClientAuthConfigRequest\"}\n\x1ePublicClientAuthConfigResponse\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\x12\x0e\n\x06scopes\x18\x03 \x03(\t\x12\"\n\x1a\x61uthorization_metadata_key\x18\x04 \x01(\t2\xfc\x03\n\x13\x41uthMetadataService\x12\xf5\x01\n\x11GetOAuth2Metadata\x12\'.flyteidl.service.OAuth2MetadataRequest\x1a(.flyteidl.service.OAuth2MetadataResponse\"\x8c\x01\x82\xd3\xe4\x93\x02)\x12\'/.well-known/oauth-authorization-server\x92\x41Z\x1aXRetrieves OAuth2 authorization server metadata. This endpoint is anonymously accessible.\x12\xec\x01\n\x15GetPublicClientConfig\x12/.flyteidl.service.PublicClientAuthConfigRequest\x1a\x30.flyteidl.service.PublicClientAuthConfigResponse\"p\x82\xd3\xe4\x93\x02\x19\x12\x17/config/v1/flyte_client\x92\x41N\x1aLRetrieves public flyte client info. This endpoint is anonymously accessible.B9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_OAUTH2METADATAREQUEST = _descriptor.Descriptor(
  name='OAuth2MetadataRequest',
  full_name='flyteidl.service.OAuth2MetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=148,
)


_OAUTH2METADATARESPONSE = _descriptor.Descriptor(
  name='OAuth2MetadataResponse',
  full_name='flyteidl.service.OAuth2MetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='flyteidl.service.OAuth2MetadataResponse.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorization_endpoint', full_name='flyteidl.service.OAuth2MetadataResponse.authorization_endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_endpoint', full_name='flyteidl.service.OAuth2MetadataResponse.token_endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_types_supported', full_name='flyteidl.service.OAuth2MetadataResponse.response_types_supported', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scopes_supported', full_name='flyteidl.service.OAuth2MetadataResponse.scopes_supported', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_endpoint_auth_methods_supported', full_name='flyteidl.service.OAuth2MetadataResponse.token_endpoint_auth_methods_supported', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jwks_uri', full_name='flyteidl.service.OAuth2MetadataResponse.jwks_uri', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code_challenge_methods_supported', full_name='flyteidl.service.OAuth2MetadataResponse.code_challenge_methods_supported', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grant_types_supported', full_name='flyteidl.service.OAuth2MetadataResponse.grant_types_supported', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=445,
)


_PUBLICCLIENTAUTHCONFIGREQUEST = _descriptor.Descriptor(
  name='PublicClientAuthConfigRequest',
  full_name='flyteidl.service.PublicClientAuthConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=478,
)


_PUBLICCLIENTAUTHCONFIGRESPONSE = _descriptor.Descriptor(
  name='PublicClientAuthConfigResponse',
  full_name='flyteidl.service.PublicClientAuthConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='flyteidl.service.PublicClientAuthConfigResponse.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='flyteidl.service.PublicClientAuthConfigResponse.redirect_uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scopes', full_name='flyteidl.service.PublicClientAuthConfigResponse.scopes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorization_metadata_key', full_name='flyteidl.service.PublicClientAuthConfigResponse.authorization_metadata_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=605,
)

DESCRIPTOR.message_types_by_name['OAuth2MetadataRequest'] = _OAUTH2METADATAREQUEST
DESCRIPTOR.message_types_by_name['OAuth2MetadataResponse'] = _OAUTH2METADATARESPONSE
DESCRIPTOR.message_types_by_name['PublicClientAuthConfigRequest'] = _PUBLICCLIENTAUTHCONFIGREQUEST
DESCRIPTOR.message_types_by_name['PublicClientAuthConfigResponse'] = _PUBLICCLIENTAUTHCONFIGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OAuth2MetadataRequest = _reflection.GeneratedProtocolMessageType('OAuth2MetadataRequest', (_message.Message,), dict(
  DESCRIPTOR = _OAUTH2METADATAREQUEST,
  __module__ = 'flyteidl.service.auth_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.OAuth2MetadataRequest)
  ))
_sym_db.RegisterMessage(OAuth2MetadataRequest)

OAuth2MetadataResponse = _reflection.GeneratedProtocolMessageType('OAuth2MetadataResponse', (_message.Message,), dict(
  DESCRIPTOR = _OAUTH2METADATARESPONSE,
  __module__ = 'flyteidl.service.auth_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.OAuth2MetadataResponse)
  ))
_sym_db.RegisterMessage(OAuth2MetadataResponse)

PublicClientAuthConfigRequest = _reflection.GeneratedProtocolMessageType('PublicClientAuthConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUBLICCLIENTAUTHCONFIGREQUEST,
  __module__ = 'flyteidl.service.auth_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.PublicClientAuthConfigRequest)
  ))
_sym_db.RegisterMessage(PublicClientAuthConfigRequest)

PublicClientAuthConfigResponse = _reflection.GeneratedProtocolMessageType('PublicClientAuthConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLICCLIENTAUTHCONFIGRESPONSE,
  __module__ = 'flyteidl.service.auth_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.PublicClientAuthConfigResponse)
  ))
_sym_db.RegisterMessage(PublicClientAuthConfigResponse)


DESCRIPTOR._options = None

_AUTHMETADATASERVICE = _descriptor.ServiceDescriptor(
  name='AuthMetadataService',
  full_name='flyteidl.service.AuthMetadataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=608,
  serialized_end=1116,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetOAuth2Metadata',
    full_name='flyteidl.service.AuthMetadataService.GetOAuth2Metadata',
    index=0,
    containing_service=None,
    input_type=_OAUTH2METADATAREQUEST,
    output_type=_OAUTH2METADATARESPONSE,
    serialized_options=_b('\202\323\344\223\002)\022\'/.well-known/oauth-authorization-server\222AZ\032XRetrieves OAuth2 authorization server metadata. This endpoint is anonymously accessible.'),
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicClientConfig',
    full_name='flyteidl.service.AuthMetadataService.GetPublicClientConfig',
    index=1,
    containing_service=None,
    input_type=_PUBLICCLIENTAUTHCONFIGREQUEST,
    output_type=_PUBLICCLIENTAUTHCONFIGRESPONSE,
    serialized_options=_b('\202\323\344\223\002\031\022\027/config/v1/flyte_client\222AN\032LRetrieves public flyte client info. This endpoint is anonymously accessible.'),
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHMETADATASERVICE)

DESCRIPTOR.services_by_name['AuthMetadataService'] = _AUTHMETADATASERVICE

# @@protoc_insertion_point(module_scope)
